# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/topic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n doublecloud/kafka/v1/topic.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xef\x02\n\x05Topic\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12;\n\npartitions\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\npartitions\x12J\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11replicationFactor\x12N\n\x10topic_config_2_8\x18\x05 \x01(\x0b\x32#.doublecloud.kafka.v1.TopicConfig28H\x00R\rtopicConfig28\x12J\n\x0etopic_config_3\x18\x07 \x01(\x0b\x32\".doublecloud.kafka.v1.TopicConfig3H\x00R\x0ctopicConfig3B\x0e\n\x0ctopic_config\"\xd4\x02\n\tTopicSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\npartitions\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\npartitions\x12J\n\x12replication_factor\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11replicationFactor\x12N\n\x10topic_config_2_8\x18\x04 \x01(\x0b\x32#.doublecloud.kafka.v1.TopicConfig28H\x00R\rtopicConfig28\x12J\n\x0etopic_config_3\x18\x06 \x01(\x0b\x32\".doublecloud.kafka.v1.TopicConfig3H\x00R\x0ctopicConfig3B\x0e\n\x0ctopic_config\"\x85\x06\n\rTopicConfig28\x12X\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x31.doublecloud.kafka.v1.TopicConfig28.CleanupPolicyR\rcleanupPolicy\x12^\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32\x33.doublecloud.kafka.v1.TopicConfig28.CompressionTypeR\x0f\x63ompressionType\x12\x44\n\x0fretention_bytes\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0eretentionBytes\x12>\n\x0cretention_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0bretentionMs\x12G\n\x11max_message_bytes\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0fmaxMessageBytes\"\x89\x01\n\rCleanupPolicy\x12\x1a\n\x16\x43LEANUP_POLICY_INVALID\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\xde\x01\n\x0f\x43ompressionType\x12\x1c\n\x18\x43OMPRESSION_TYPE_INVALID\x10\x00\x12!\n\x1d\x43OMPRESSION_TYPE_UNCOMPRESSED\x10\x01\x12\x19\n\x15\x43OMPRESSION_TYPE_ZSTD\x10\x02\x12\x18\n\x14\x43OMPRESSION_TYPE_LZ4\x10\x03\x12\x1b\n\x17\x43OMPRESSION_TYPE_SNAPPY\x10\x04\x12\x19\n\x15\x43OMPRESSION_TYPE_GZIP\x10\x05\x12\x1d\n\x19\x43OMPRESSION_TYPE_PRODUCER\x10\x06\"\x82\x06\n\x0cTopicConfig3\x12W\n\x0e\x63leanup_policy\x18\x01 \x01(\x0e\x32\x30.doublecloud.kafka.v1.TopicConfig3.CleanupPolicyR\rcleanupPolicy\x12]\n\x10\x63ompression_type\x18\x02 \x01(\x0e\x32\x32.doublecloud.kafka.v1.TopicConfig3.CompressionTypeR\x0f\x63ompressionType\x12\x44\n\x0fretention_bytes\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0eretentionBytes\x12>\n\x0cretention_ms\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0bretentionMs\x12G\n\x11max_message_bytes\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0fmaxMessageBytes\"\x89\x01\n\rCleanupPolicy\x12\x1a\n\x16\x43LEANUP_POLICY_INVALID\x10\x00\x12\x19\n\x15\x43LEANUP_POLICY_DELETE\x10\x01\x12\x1a\n\x16\x43LEANUP_POLICY_COMPACT\x10\x02\x12%\n!CLEANUP_POLICY_COMPACT_AND_DELETE\x10\x03\"\xde\x01\n\x0f\x43ompressionType\x12\x1c\n\x18\x43OMPRESSION_TYPE_INVALID\x10\x00\x12!\n\x1d\x43OMPRESSION_TYPE_UNCOMPRESSED\x10\x01\x12\x19\n\x15\x43OMPRESSION_TYPE_ZSTD\x10\x02\x12\x18\n\x14\x43OMPRESSION_TYPE_LZ4\x10\x03\x12\x1b\n\x17\x43OMPRESSION_TYPE_SNAPPY\x10\x04\x12\x19\n\x15\x43OMPRESSION_TYPE_GZIP\x10\x05\x12\x1d\n\x19\x43OMPRESSION_TYPE_PRODUCER\x10\x06\x42\x37Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.topic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_TOPIC']._serialized_start=91
  _globals['_TOPIC']._serialized_end=458
  _globals['_TOPICSPEC']._serialized_start=461
  _globals['_TOPICSPEC']._serialized_end=801
  _globals['_TOPICCONFIG28']._serialized_start=804
  _globals['_TOPICCONFIG28']._serialized_end=1577
  _globals['_TOPICCONFIG28_CLEANUPPOLICY']._serialized_start=1215
  _globals['_TOPICCONFIG28_CLEANUPPOLICY']._serialized_end=1352
  _globals['_TOPICCONFIG28_COMPRESSIONTYPE']._serialized_start=1355
  _globals['_TOPICCONFIG28_COMPRESSIONTYPE']._serialized_end=1577
  _globals['_TOPICCONFIG3']._serialized_start=1580
  _globals['_TOPICCONFIG3']._serialized_end=2350
  _globals['_TOPICCONFIG3_CLEANUPPOLICY']._serialized_start=1215
  _globals['_TOPICCONFIG3_CLEANUPPOLICY']._serialized_end=1352
  _globals['_TOPICCONFIG3_COMPRESSIONTYPE']._serialized_start=1355
  _globals['_TOPICCONFIG3_COMPRESSIONTYPE']._serialized_end=1577
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/network/v1/network_connection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/doublecloud/network/v1/network_connection.proto\x12\x16\x64oublecloud.network.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xff\x04\n\x11NetworkConnection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nnetwork_id\x18\x02 \x01(\tR\tnetworkId\x12\x44\n\x03\x61ws\x18\x04 \x01(\x0b\x32\x30.doublecloud.network.v1.AWSNetworkConnectionInfoH\x00R\x03\x61ws\x12;\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12 \n\x0b\x64\x65scription\x18\x08 \x01(\tR\x0b\x64\x65scription\x12Y\n\x06status\x18\t \x01(\x0e\x32\x41.doublecloud.network.v1.NetworkConnection.NetworkConnectionStatusR\x06status\x12#\n\rstatus_reason\x18\n \x01(\tR\x0cstatusReason\"\x82\x02\n\x17NetworkConnectionStatus\x12%\n!NETWORK_CONNECTION_STATUS_INVALID\x10\x00\x12&\n\"NETWORK_CONNECTION_STATUS_CREATING\x10\x01\x12%\n!NETWORK_CONNECTION_STATUS_PENDING\x10\x02\x12$\n NETWORK_CONNECTION_STATUS_ACTIVE\x10\x03\x12&\n\"NETWORK_CONNECTION_STATUS_DELETING\x10\x04\x12#\n\x1fNETWORK_CONNECTION_STATUS_ERROR\x10\x05\x42\x11\n\x0f\x63onnection_info\"w\n\x18\x41WSNetworkConnectionInfo\x12S\n\x07peering\x18\x01 \x01(\x0b\x32\x37.doublecloud.network.v1.AWSNetworkConnectionPeeringInfoH\x00R\x07peeringB\x06\n\x04type\"\xe6\x02\n\x1f\x41WSNetworkConnectionPeeringInfo\x12\x15\n\x06vpc_id\x18\x01 \x01(\tR\x05vpcId\x12\x1d\n\naccount_id\x18\x02 \x01(\tR\taccountId\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12&\n\x0fipv4_cidr_block\x18\x04 \x01(\tR\ripv4CidrBlock\x12&\n\x0fipv6_cidr_block\x18\x05 \x01(\tR\ripv6CidrBlock\x12\x32\n\x15peering_connection_id\x18\x06 \x01(\tR\x13peeringConnectionId\x12\x35\n\x17managed_ipv4_cidr_block\x18\x07 \x01(\tR\x14managedIpv4CidrBlock\x12\x35\n\x17managed_ipv6_cidr_block\x18\x08 \x01(\tR\x14managedIpv6CidrBlockB;Z9github.com/doublecloud/api/doublecloud/network/v1;networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.network.v1.network_connection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/doublecloud/api/doublecloud/network/v1;network'
  _globals['_NETWORKCONNECTION']._serialized_start=109
  _globals['_NETWORKCONNECTION']._serialized_end=748
  _globals['_NETWORKCONNECTION_NETWORKCONNECTIONSTATUS']._serialized_start=471
  _globals['_NETWORKCONNECTION_NETWORKCONNECTIONSTATUS']._serialized_end=729
  _globals['_AWSNETWORKCONNECTIONINFO']._serialized_start=750
  _globals['_AWSNETWORKCONNECTIONINFO']._serialized_end=869
  _globals['_AWSNETWORKCONNECTIONPEERINGINFO']._serialized_start=872
  _globals['_AWSNETWORKCONNECTIONPEERINGINFO']._serialized_end=1230
# @@protoc_insertion_point(module_scope)



from doublecloud._retry_interceptor import (  # noqa: F401; pylint: disable=unused-import
    RetryInterceptor,
)
from doublecloud._sdk import SDK  # noqa: F401; pylint: disable=unused-import

__version__ = "0.0.1"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import topic_pb2 as doublecloud_dot_kafka_dot_v1_dot_topic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(doublecloud/kafka/v1/topic_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a doublecloud/kafka/v1/topic.proto\"O\n\x0fGetTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName\"b\n\x11ListTopicsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x80\x01\n\x12ListTopicsResponse\x12\x33\n\x06topics\x18\x01 \x03(\x0b\x32\x1b.doublecloud.kafka.v1.TopicR\x06topics\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"s\n\x12\x43reateTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12>\n\ntopic_spec\x18\x02 \x01(\x0b\x32\x1f.doublecloud.kafka.v1.TopicSpecR\ttopicSpec\"\x92\x01\n\x12UpdateTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName\x12>\n\ntopic_spec\x18\x03 \x01(\x0b\x32\x1f.doublecloud.kafka.v1.TopicSpecR\ttopicSpec\"R\n\x12\x44\x65leteTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName2\xa1\x03\n\x0cTopicService\x12I\n\x03Get\x12%.doublecloud.kafka.v1.GetTopicRequest\x1a\x1b.doublecloud.kafka.v1.Topic\x12Y\n\x04List\x12\'.doublecloud.kafka.v1.ListTopicsRequest\x1a(.doublecloud.kafka.v1.ListTopicsResponse\x12M\n\x06\x43reate\x12(.doublecloud.kafka.v1.CreateTopicRequest\x1a\x19.doublecloud.v1.Operation\x12M\n\x06Update\x12(.doublecloud.kafka.v1.UpdateTopicRequest\x1a\x19.doublecloud.v1.Operation\x12M\n\x06\x44\x65lete\x12(.doublecloud.kafka.v1.DeleteTopicRequest\x1a\x19.doublecloud.v1.OperationB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.topic_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_GETTOPICREQUEST']._serialized_start=161
  _globals['_GETTOPICREQUEST']._serialized_end=240
  _globals['_LISTTOPICSREQUEST']._serialized_start=242
  _globals['_LISTTOPICSREQUEST']._serialized_end=340
  _globals['_LISTTOPICSRESPONSE']._serialized_start=343
  _globals['_LISTTOPICSRESPONSE']._serialized_end=471
  _globals['_CREATETOPICREQUEST']._serialized_start=473
  _globals['_CREATETOPICREQUEST']._serialized_end=588
  _globals['_UPDATETOPICREQUEST']._serialized_start=591
  _globals['_UPDATETOPICREQUEST']._serialized_end=737
  _globals['_DELETETOPICREQUEST']._serialized_start=739
  _globals['_DELETETOPICREQUEST']._serialized_end=821
  _globals['_TOPICSERVICE']._serialized_start=824
  _globals['_TOPICSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.visualization.v1 import workbook_service_pb2 as doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2


class WorkbookServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Get',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Create',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Update',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Delete',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.GetConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/GetConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.FromString,
                )
        self.CreateConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/CreateConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/UpdateConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/DeleteConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.AdviseDatasetFields = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/AdviseDatasetFields',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.FromString,
                )


class WorkbookServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Workbook operations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnection(self, request, context):
        """Connections operations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdviseDatasetFields(self, request, context):
        """List all direct fields of dataset with configured data source
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkbookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AdviseDatasetFields': grpc.unary_unary_rpc_method_handler(
                    servicer.AdviseDatasetFields,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'doublecloud.visualization.v1.WorkbookService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkbookService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Get',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Create',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Update',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Delete',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/GetConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/CreateConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/UpdateConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/DeleteConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdviseDatasetFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/AdviseDatasetFields',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/linkedin_ads_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBdoublecloud/transfer/v1/endpoint/airbyte/linkedin_ads_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\xd9\x03\n\x11LinkedinAdsSource\x12\x1d\n\nstart_date\x18\x01 \x01(\tR\tstartDate\x12\x1f\n\x0b\x61\x63\x63ount_ids\x18\x02 \x03(\x03R\naccountIds\x12i\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32G.doublecloud.transfer.v1.endpoint.airbyte.LinkedinAdsSource.CredentialsR\x0b\x63redentials\x1a\x98\x02\n\x0b\x43redentials\x12\x65\n\x05oauth\x18\x01 \x01(\x0b\x32M.doublecloud.transfer.v1.endpoint.airbyte.LinkedinAdsSource.Credentials.OAuthH\x00R\x05oauth\x12#\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\tH\x00R\x0b\x61\x63\x63\x65ssToken\x1an\n\x05OAuth\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x02 \x01(\tR\x0c\x63lientSecret\x12#\n\rrefresh_token\x18\x03 \x01(\tR\x0crefreshTokenB\r\n\x0b\x63redentialsBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.linkedin_ads_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_LINKEDINADSSOURCE']._serialized_start=113
  _globals['_LINKEDINADSSOURCE']._serialized_end=586
  _globals['_LINKEDINADSSOURCE_CREDENTIALS']._serialized_start=306
  _globals['_LINKEDINADSSOURCE_CREDENTIALS']._serialized_end=586
  _globals['_LINKEDINADSSOURCE_CREDENTIALS_OAUTH']._serialized_start=461
  _globals['_LINKEDINADSSOURCE_CREDENTIALS_OAUTH']._serialized_end=571
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64oublecloud/kafka/v1/user.proto\x12\x14\x64oublecloud.kafka.v1\"}\n\x04User\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x42\n\x0bpermissions\x18\x03 \x03(\x0b\x32 .doublecloud.kafka.v1.PermissionR\x0bpermissions\"~\n\x08UserSpec\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x42\n\x0bpermissions\x18\x03 \x03(\x0b\x32 .doublecloud.kafka.v1.PermissionR\x0bpermissions\"\xde\x01\n\nPermission\x12\x1d\n\ntopic_name\x18\x01 \x01(\tR\ttopicName\x12?\n\x04role\x18\x02 \x01(\x0e\x32+.doublecloud.kafka.v1.Permission.AccessRoleR\x04role\"p\n\nAccessRole\x12\x17\n\x13\x41\x43\x43\x45SS_ROLE_INVALID\x10\x00\x12\x18\n\x14\x41\x43\x43\x45SS_ROLE_PRODUCER\x10\x01\x12\x18\n\x14\x41\x43\x43\x45SS_ROLE_CONSUMER\x10\x02\x12\x15\n\x11\x41\x43\x43\x45SS_ROLE_ADMIN\x10\x03\x42\x37Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_USER']._serialized_start=57
  _globals['_USER']._serialized_end=182
  _globals['_USERSPEC']._serialized_start=184
  _globals['_USERSPEC']._serialized_end=310
  _globals['_PERMISSION']._serialized_start=313
  _globals['_PERMISSION']._serialized_end=535
  _globals['_PERMISSION_ACCESSROLE']._serialized_start=423
  _globals['_PERMISSION_ACCESSROLE']._serialized_end=535
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/postgres.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/doublecloud/transfer/v1/endpoint/postgres.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\x8b\x0c\n\x1ePostgresObjectTransferSettings\x12Q\n\x08sequence\x18\x01 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x08sequence\x12\x61\n\x11sequence_owned_by\x18\x02 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0fsequenceOwnedBy\x12X\n\x0csequence_set\x18\x12 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0bsequenceSet\x12K\n\x05table\x18\x03 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x05table\x12V\n\x0bprimary_key\x18\x04 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\nprimaryKey\x12Z\n\rfk_constraint\x18\x05 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0c\x66kConstraint\x12\\\n\x0e\x64\x65\x66\x61ult_values\x18\x06 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\rdefaultValues\x12U\n\nconstraint\x18\x07 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\nconstraint\x12K\n\x05index\x18\x08 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x05index\x12I\n\x04view\x18\t \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04view\x12\x62\n\x11materialized_view\x18\x11 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x10materializedView\x12Q\n\x08\x66unction\x18\n \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x08\x66unction\x12O\n\x07trigger\x18\x0b \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x07trigger\x12I\n\x04type\x18\x0c \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04type\x12I\n\x04rule\x18\r \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04rule\x12S\n\tcollation\x18\x0e \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\tcollation\x12M\n\x06policy\x18\x0f \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x06policy\x12I\n\x04\x63\x61st\x18\x10 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04\x63\x61st\"\x83\x01\n\x11OnPremisePostgres\x12\x14\n\x05hosts\x18\x05 \x03(\tR\x05hosts\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x44\n\x08tls_mode\x18\x06 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\"x\n\x12PostgresConnection\x12T\n\non_premise\x18\x02 \x01(\x0b\x32\x33.doublecloud.transfer.v1.endpoint.OnPremisePostgresH\x00R\tonPremiseB\x0c\n\nconnection\"\xfc\x03\n\x0ePostgresSource\x12T\n\nconnection\x18\x01 \x01(\x0b\x32\x34.doublecloud.transfer.v1.endpoint.PostgresConnectionR\nconnection\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12%\n\x0einclude_tables\x18\x05 \x03(\tR\rincludeTables\x12%\n\x0e\x65xclude_tables\x18\x06 \x03(\tR\rexcludeTables\x12-\n\x13slot_byte_lag_limit\x18\x08 \x01(\x03R\x10slotByteLagLimit\x12%\n\x0eservice_schema\x18\t \x01(\tR\rserviceSchema\x12z\n\x18object_transfer_settings\x18\r \x01(\x0b\x32@.doublecloud.transfer.v1.endpoint.PostgresObjectTransferSettingsR\x16objectTransferSettings\"\xdd\x02\n\x0ePostgresTarget\x12T\n\nconnection\x18\x01 \x01(\x0b\x32\x34.doublecloud.transfer.v1.endpoint.PostgresConnectionR\nconnection\x12\'\n\x0fsecurity_groups\x18\x07 \x03(\tR\x0esecurityGroups\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12V\n\x0e\x63leanup_policy\x18\x05 \x01(\x0e\x32/.doublecloud.transfer.v1.endpoint.CleanupPolicyR\rcleanupPolicyBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.postgres_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_start=133
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_end=1680
  _globals['_ONPREMISEPOSTGRES']._serialized_start=1683
  _globals['_ONPREMISEPOSTGRES']._serialized_end=1814
  _globals['_POSTGRESCONNECTION']._serialized_start=1816
  _globals['_POSTGRESCONNECTION']._serialized_end=1936
  _globals['_POSTGRESSOURCE']._serialized_start=1939
  _globals['_POSTGRESSOURCE']._serialized_end=2447
  _globals['_POSTGRESTARGET']._serialized_start=2450
  _globals['_POSTGRESTARGET']._serialized_end=2799
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from doublecloud.v1 import cluster_pb2 as doublecloud_dot_v1_dot_cluster__pb2
from doublecloud.v1 import maintenance_pb2 as doublecloud_dot_v1_dot_maintenance__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import cluster_pb2 as doublecloud_dot_kafka_dot_v1_dot_cluster__pb2
from doublecloud.kafka.v1 import config_pb2 as doublecloud_dot_kafka_dot_v1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*doublecloud/kafka/v1/cluster_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1c\x64oublecloud/v1/cluster.proto\x1a doublecloud/v1/maintenance.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a\"doublecloud/kafka/v1/cluster.proto\x1a!doublecloud/kafka/v1/config.proto\"P\n\x11GetClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1c\n\tsensitive\x18\x02 \x01(\x08R\tsensitive\"\x9b\x01\n\x13ListClustersRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\x12\x35\n\x04view\x18\x03 \x01(\x0e\x32!.doublecloud.kafka.v1.ClusterViewR\x04view\"\x88\x01\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1d.doublecloud.kafka.v1.ClusterR\x08\x63lusters\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xae\x04\n\x14\x43reateClusterRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x02 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\x12\x44\n\tresources\x18\x07 \x01(\x0b\x32&.doublecloud.kafka.v1.ClusterResourcesR\tresources\x12.\n\x06\x61\x63\x63\x65ss\x18\x08 \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12>\n\nencryption\x18\t \x01(\x0b\x32\x1e.doublecloud.v1.DataEncryptionR\nencryption\x12\x1d\n\nnetwork_id\x18\n \x01(\tR\tnetworkId\x12P\n\x12maintenance_window\x18\x0b \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12\x44\n\x0ckafka_config\x18\x0c \x01(\x0b\x32!.doublecloud.kafka.v1.KafkaConfigR\x0bkafkaConfig\"\x93\x03\n\x14UpdateClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x12\x44\n\tresources\x18\x05 \x01(\x0b\x32&.doublecloud.kafka.v1.ClusterResourcesR\tresources\x12.\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12P\n\x12maintenance_window\x18\x07 \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12\x44\n\x0ckafka_config\x18\x08 \x01(\x0b\x32!.doublecloud.kafka.v1.KafkaConfigR\x0bkafkaConfig\"5\n\x14\x44\x65leteClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"?\n\x1eResetClusterCredentialsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"h\n\x17ListClusterHostsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x83\x01\n\x18ListClusterHostsResponse\x12\x30\n\x05hosts\x18\x01 \x03(\x0b\x32\x1a.doublecloud.kafka.v1.HostR\x05hosts\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"4\n\x13StartClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"3\n\x12StopClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"\xd0\x01\n\x1cRescheduleMaintenanceRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12G\n\x0freschedule_type\x18\x02 \x01(\x0e\x32\x1e.doublecloud.v1.RescheduleTypeR\x0erescheduleType\x12H\n\x12\x64\x65layed_until_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x64\x65layedUntilTime\"m\n\x1cListClusterOperationsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x91\x01\n\x1dListClusterOperationsResponse\x12\x39\n\noperations\x18\x01 \x03(\x0b\x32\x19.doublecloud.v1.OperationR\noperations\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage*V\n\x0b\x43lusterView\x12\x18\n\x14\x43LUSTER_VIEW_INVALID\x10\x00\x12\x16\n\x12\x43LUSTER_VIEW_BASIC\x10\x01\x12\x15\n\x11\x43LUSTER_VIEW_FULL\x10\x02\x32\x81\x08\n\x0e\x43lusterService\x12M\n\x03Get\x12\'.doublecloud.kafka.v1.GetClusterRequest\x1a\x1d.doublecloud.kafka.v1.Cluster\x12]\n\x04List\x12).doublecloud.kafka.v1.ListClustersRequest\x1a*.doublecloud.kafka.v1.ListClustersResponse\x12O\n\x06\x43reate\x12*.doublecloud.kafka.v1.CreateClusterRequest\x1a\x19.doublecloud.v1.Operation\x12O\n\x06Update\x12*.doublecloud.kafka.v1.UpdateClusterRequest\x1a\x19.doublecloud.v1.Operation\x12O\n\x06\x44\x65lete\x12*.doublecloud.kafka.v1.DeleteClusterRequest\x1a\x19.doublecloud.v1.Operation\x12\x63\n\x10ResetCredentials\x12\x34.doublecloud.kafka.v1.ResetClusterCredentialsRequest\x1a\x19.doublecloud.v1.Operation\x12j\n\tListHosts\x12-.doublecloud.kafka.v1.ListClusterHostsRequest\x1a..doublecloud.kafka.v1.ListClusterHostsResponse\x12M\n\x05Start\x12).doublecloud.kafka.v1.StartClusterRequest\x1a\x19.doublecloud.v1.Operation\x12K\n\x04Stop\x12(.doublecloud.kafka.v1.StopClusterRequest\x1a\x19.doublecloud.v1.Operation\x12\x66\n\x15RescheduleMaintenance\x12\x32.doublecloud.kafka.v1.RescheduleMaintenanceRequest\x1a\x19.doublecloud.v1.Operation\x12y\n\x0eListOperations\x12\x32.doublecloud.kafka.v1.ListClusterOperationsRequest\x1a\x33.doublecloud.kafka.v1.ListClusterOperationsResponseB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_CLUSTERVIEW']._serialized_start=2580
  _globals['_CLUSTERVIEW']._serialized_end=2666
  _globals['_GETCLUSTERREQUEST']._serialized_start=297
  _globals['_GETCLUSTERREQUEST']._serialized_end=377
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=380
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=535
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=538
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=674
  _globals['_CREATECLUSTERREQUEST']._serialized_start=677
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1235
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1238
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1641
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1643
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1696
  _globals['_RESETCLUSTERCREDENTIALSREQUEST']._serialized_start=1698
  _globals['_RESETCLUSTERCREDENTIALSREQUEST']._serialized_end=1761
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=1763
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=1867
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=1870
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=2001
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2003
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2055
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2057
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2108
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=2111
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=2319
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2321
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2430
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2433
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=2578
  _globals['_CLUSTERSERVICE']._serialized_start=2669
  _globals['_CLUSTERSERVICE']._serialized_end=3694
# @@protoc_insertion_point(module_scope)



import os

import pkg_resources

try:
    VERSION = pkg_resources.get_distribution("doublecloud").version
except pkg_resources.DistributionNotFound:
    VERSION = "0.0.0"

SDK_USER_AGENT = f"doublecloud-python-sdk/{VERSION}"

OPERATIONS_PREFIX_MAP = {
    "clickhouse": "cho",
    "kafka": "kfo",
    "transfer": "dtj",
    "transfer_endpoints": "dte",
}


def get_endpoint():
    return os.environ.get("DC_ENDPOINT", "double.cloud")



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/version.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"doublecloud/kafka/v1/version.proto\x12\x14\x64oublecloud.kafka.v1\"p\n\x07Version\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ndeprecated\x18\x03 \x01(\x08R\ndeprecated\x12!\n\x0cupdatable_to\x18\x04 \x03(\tR\x0bupdatableToB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.version_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_VERSION']._serialized_start=60
  _globals['_VERSION']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/version_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import version_pb2 as doublecloud_dot_kafka_dot_v1_dot_version__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*doublecloud/kafka/v1/version_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1b\x64oublecloud/v1/paging.proto\x1a\"doublecloud/kafka/v1/version.proto\"E\n\x13ListVersionsRequest\x12.\n\x06paging\x18\x01 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x88\x01\n\x14ListVersionsResponse\x12\x39\n\x08versions\x18\x01 \x03(\x0b\x32\x1d.doublecloud.kafka.v1.VersionR\x08versions\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage2o\n\x0eVersionService\x12]\n\x04List\x12).doublecloud.kafka.v1.ListVersionsRequest\x1a*.doublecloud.kafka.v1.ListVersionsResponseB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.version_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_LISTVERSIONSREQUEST']._serialized_start=133
  _globals['_LISTVERSIONSREQUEST']._serialized_end=202
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=205
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=341
  _globals['_VERSIONSERVICE']._serialized_start=343
  _globals['_VERSIONSERVICE']._serialized_end=454
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/amazon_ads_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@doublecloud/transfer/v1/endpoint/airbyte/amazon_ads_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\xe1\x01\n\x0f\x41mazonAdsSource\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x02 \x01(\tR\x0c\x63lientSecret\x12\x14\n\x05scope\x18\x03 \x01(\tR\x05scope\x12#\n\rrefresh_token\x18\x04 \x01(\tR\x0crefreshToken\x12\x1d\n\nstart_date\x18\x05 \x01(\tR\tstartDate\x12\x16\n\x06region\x18\x06 \x01(\tR\x06region\x12\x1a\n\x08profiles\x18\x07 \x03(\x01R\x08profilesBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.amazon_ads_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_AMAZONADSSOURCE']._serialized_start=111
  _globals['_AMAZONADSSOURCE']._serialized_end=336
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/parsers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/transfer/v1/endpoint/parsers.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\xc6\x01\n\x06Parser\x12X\n\x0bjson_parser\x18\x01 \x01(\x0b\x32\x35.doublecloud.transfer.v1.endpoint.GenericParserCommonH\x00R\njsonParser\x12X\n\x0btskv_parser\x18\x06 \x01(\x0b\x32\x35.doublecloud.transfer.v1.endpoint.GenericParserCommonH\x00R\ntskvParserB\x08\n\x06parser\"\xb8\x01\n\x13GenericParserCommon\x12M\n\x0b\x64\x61ta_schema\x18\x01 \x01(\x0b\x32,.doublecloud.transfer.v1.endpoint.DataSchemaR\ndataSchema\x12*\n\x11null_keys_allowed\x18\x02 \x01(\x08R\x0fnullKeysAllowed\x12&\n\x0f\x61\x64\x64_rest_column\x18\x03 \x01(\x08R\raddRestColumnBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.parsers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_PARSER']._serialized_start=132
  _globals['_PARSER']._serialized_end=330
  _globals['_GENERICPARSERCOMMON']._serialized_start=333
  _globals['_GENERICPARSERCOMMON']._serialized_end=517
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/mongo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,doublecloud/transfer/v1/endpoint/mongo.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\xa1\x01\n\x0eOnPremiseMongo\x12\x14\n\x05hosts\x18\x01 \x03(\tR\x05hosts\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x44\n\x08tls_mode\x18\x06 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\x12\x1f\n\x0breplica_set\x18\x05 \x01(\tR\nreplicaSet\"\xf1\x01\n\x16MongoConnectionOptions\x12Q\n\non_premise\x18\x02 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.OnPremiseMongoH\x00R\tonPremise\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12\x1f\n\x0b\x61uth_source\x18\x05 \x01(\tR\nauthSourceB\t\n\x07\x61\x64\x64ress\"\x8a\x01\n\x0fMongoConnection\x12i\n\x12\x63onnection_options\x18\x03 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.MongoConnectionOptionsH\x00R\x11\x63onnectionOptionsB\x0c\n\nconnection\"_\n\x0fMongoCollection\x12#\n\rdatabase_name\x18\x01 \x01(\tR\x0c\x64\x61tabaseName\x12\'\n\x0f\x63ollection_name\x18\x02 \x01(\tR\x0e\x63ollectionName\"\xd5\x02\n\x0bMongoSource\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoConnectionR\nconnection\x12S\n\x0b\x63ollections\x18\x06 \x03(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoCollectionR\x0b\x63ollections\x12\x64\n\x14\x65xcluded_collections\x18\x07 \x03(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoCollectionR\x13\x65xcludedCollections\x12\x38\n\x18secondary_preferred_mode\x18\x08 \x01(\x08R\x16secondaryPreferredMode\"\xd4\x01\n\x0bMongoTarget\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoConnectionR\nconnection\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12V\n\x0e\x63leanup_policy\x18\x06 \x01(\x0e\x32/.doublecloud.transfer.v1.endpoint.CleanupPolicyR\rcleanupPolicyBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.mongo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_ONPREMISEMONGO']._serialized_start=130
  _globals['_ONPREMISEMONGO']._serialized_end=291
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_start=294
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_end=535
  _globals['_MONGOCONNECTION']._serialized_start=538
  _globals['_MONGOCONNECTION']._serialized_end=676
  _globals['_MONGOCOLLECTION']._serialized_start=678
  _globals['_MONGOCOLLECTION']._serialized_end=773
  _globals['_MONGOSOURCE']._serialized_start=776
  _globals['_MONGOSOURCE']._serialized_end=1117
  _globals['_MONGOTARGET']._serialized_start=1120
  _globals['_MONGOTARGET']._serialized_end=1332
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/visualization/v1/workbook_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.visualization.v1 import workbook_pb2 as doublecloud_dot_visualization_dot_v1_dot_workbook__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3doublecloud/visualization/v1/workbook_service.proto\x12\x1c\x64oublecloud.visualization.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a+doublecloud/visualization/v1/workbook.proto\"5\n\x12GetWorkbookRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\"Y\n\x13GetWorkbookResponse\x12\x42\n\x08workbook\x18\x01 \x01(\x0b\x32&.doublecloud.visualization.v1.WorkbookR\x08workbook\"]\n\x15\x43reateWorkbookRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12%\n\x0eworkbook_title\x18\x02 \x01(\tR\rworkbookTitle\"\xbd\x01\n\x15UpdateWorkbookRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\x42\n\x08workbook\x18\x02 \x01(\x0b\x32&.doublecloud.visualization.v1.WorkbookR\x08workbook\x12?\n\rforce_rewrite\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0c\x66orceRewrite\"8\n\x15\x44\x65leteWorkbookRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\"h\n\x1cGetWorkbookConnectionRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\'\n\x0f\x63onnection_name\x18\x02 \x01(\tR\x0e\x63onnectionName\"i\n\x1dGetWorkbookConnectionResponse\x12H\n\nconnection\x18\x01 \x01(\x0b\x32(.doublecloud.visualization.v1.ConnectionR\nconnection\"\xf3\x01\n\x1f\x43reateWorkbookConnectionRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\'\n\x0f\x63onnection_name\x18\x02 \x01(\tR\x0e\x63onnectionName\x12H\n\nconnection\x18\x03 \x01(\x0b\x32(.doublecloud.visualization.v1.ConnectionR\nconnection\x12<\n\x06secret\x18\x04 \x01(\x0b\x32$.doublecloud.visualization.v1.SecretR\x06secret\"\xf3\x01\n\x1fUpdateWorkbookConnectionRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\'\n\x0f\x63onnection_name\x18\x02 \x01(\tR\x0e\x63onnectionName\x12H\n\nconnection\x18\x03 \x01(\x0b\x32(.doublecloud.visualization.v1.ConnectionR\nconnection\x12<\n\x06secret\x18\x04 \x01(\x0b\x32$.doublecloud.visualization.v1.SecretR\x06secret\"k\n\x1f\x44\x65leteWorkbookConnectionRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\'\n\x0f\x63onnection_name\x18\x02 \x01(\tR\x0e\x63onnectionName\"\xb6\x01\n\x1a\x41\x64viseDatasetFieldsRequest\x12\x1f\n\x0bworkbook_id\x18\x01 \x01(\tR\nworkbookId\x12\'\n\x0f\x63onnection_name\x18\x02 \x01(\tR\x0e\x63onnectionName\x12N\n\x0fpartial_dataset\x18\x03 \x01(\x0b\x32%.doublecloud.visualization.v1.DatasetR\x0epartialDataset\"^\n\x1b\x41\x64viseDatasetFieldsResponse\x12?\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32%.doublecloud.visualization.v1.DatasetR\x07\x64\x61taset2\xed\x07\n\x0fWorkbookService\x12j\n\x03Get\x12\x30.doublecloud.visualization.v1.GetWorkbookRequest\x1a\x31.doublecloud.visualization.v1.GetWorkbookResponse\x12X\n\x06\x43reate\x12\x33.doublecloud.visualization.v1.CreateWorkbookRequest\x1a\x19.doublecloud.v1.Operation\x12X\n\x06Update\x12\x33.doublecloud.visualization.v1.UpdateWorkbookRequest\x1a\x19.doublecloud.v1.Operation\x12X\n\x06\x44\x65lete\x12\x33.doublecloud.visualization.v1.DeleteWorkbookRequest\x1a\x19.doublecloud.v1.Operation\x12\x88\x01\n\rGetConnection\x12:.doublecloud.visualization.v1.GetWorkbookConnectionRequest\x1a;.doublecloud.visualization.v1.GetWorkbookConnectionResponse\x12l\n\x10\x43reateConnection\x12=.doublecloud.visualization.v1.CreateWorkbookConnectionRequest\x1a\x19.doublecloud.v1.Operation\x12l\n\x10UpdateConnection\x12=.doublecloud.visualization.v1.UpdateWorkbookConnectionRequest\x1a\x19.doublecloud.v1.Operation\x12l\n\x10\x44\x65leteConnection\x12=.doublecloud.visualization.v1.DeleteWorkbookConnectionRequest\x1a\x19.doublecloud.v1.Operation\x12\x8a\x01\n\x13\x41\x64viseDatasetFields\x12\x38.doublecloud.visualization.v1.AdviseDatasetFieldsRequest\x1a\x39.doublecloud.visualization.v1.AdviseDatasetFieldsResponseBGZEgithub.com/doublecloud/api/doublecloud/visualization/v1;visualizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.visualization.v1.workbook_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZEgithub.com/doublecloud/api/doublecloud/visualization/v1;visualization'
  _globals['_GETWORKBOOKREQUEST']._serialized_start=194
  _globals['_GETWORKBOOKREQUEST']._serialized_end=247
  _globals['_GETWORKBOOKRESPONSE']._serialized_start=249
  _globals['_GETWORKBOOKRESPONSE']._serialized_end=338
  _globals['_CREATEWORKBOOKREQUEST']._serialized_start=340
  _globals['_CREATEWORKBOOKREQUEST']._serialized_end=433
  _globals['_UPDATEWORKBOOKREQUEST']._serialized_start=436
  _globals['_UPDATEWORKBOOKREQUEST']._serialized_end=625
  _globals['_DELETEWORKBOOKREQUEST']._serialized_start=627
  _globals['_DELETEWORKBOOKREQUEST']._serialized_end=683
  _globals['_GETWORKBOOKCONNECTIONREQUEST']._serialized_start=685
  _globals['_GETWORKBOOKCONNECTIONREQUEST']._serialized_end=789
  _globals['_GETWORKBOOKCONNECTIONRESPONSE']._serialized_start=791
  _globals['_GETWORKBOOKCONNECTIONRESPONSE']._serialized_end=896
  _globals['_CREATEWORKBOOKCONNECTIONREQUEST']._serialized_start=899
  _globals['_CREATEWORKBOOKCONNECTIONREQUEST']._serialized_end=1142
  _globals['_UPDATEWORKBOOKCONNECTIONREQUEST']._serialized_start=1145
  _globals['_UPDATEWORKBOOKCONNECTIONREQUEST']._serialized_end=1388
  _globals['_DELETEWORKBOOKCONNECTIONREQUEST']._serialized_start=1390
  _globals['_DELETEWORKBOOKCONNECTIONREQUEST']._serialized_end=1497
  _globals['_ADVISEDATASETFIELDSREQUEST']._serialized_start=1500
  _globals['_ADVISEDATASETFIELDSREQUEST']._serialized_end=1682
  _globals['_ADVISEDATASETFIELDSRESPONSE']._serialized_start=1684
  _globals['_ADVISEDATASETFIELDSRESPONSE']._serialized_end=1778
  _globals['_WORKBOOKSERVICE']._serialized_start=1781
  _globals['_WORKBOOKSERVICE']._serialized_end=2786
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import user_pb2 as doublecloud_dot_kafka_dot_v1_dot_user__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'doublecloud/kafka/v1/user_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a\x1f\x64oublecloud/kafka/v1/user.proto\x1a\x1egoogle/protobuf/wrappers.proto\"L\n\x0eGetUserRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\"a\n\x10ListUsersRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"|\n\x11ListUsersResponse\x12\x30\n\x05users\x18\x01 \x03(\x0b\x32\x1a.doublecloud.kafka.v1.UserR\x05users\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"o\n\x11\x43reateUserRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12;\n\tuser_spec\x18\x02 \x01(\x0b\x32\x1e.doublecloud.kafka.v1.UserSpecR\x08userSpec\"\xae\x03\n\x11UpdateUserRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\x12S\n\x0bupdate_spec\x18\x03 \x01(\x0b\x32\x32.doublecloud.kafka.v1.UpdateUserRequest.UpdateSpecR\nupdateSpec\x1a\x87\x02\n\nUpdateSpec\x12\x38\n\x08password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08password\x12\x66\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x44.doublecloud.kafka.v1.UpdateUserRequest.UpdateSpec.UpdatePermissionsR\x0bpermissions\x1aW\n\x11UpdatePermissions\x12\x42\n\x0bpermissions\x18\x01 \x03(\x0b\x32 .doublecloud.kafka.v1.PermissionR\x0bpermissions\"O\n\x11\x44\x65leteUserRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\"\x9a\x01\n\x1aGrantUserPermissionRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\x12@\n\npermission\x18\x03 \x01(\x0b\x32 .doublecloud.kafka.v1.PermissionR\npermission\"\x9b\x01\n\x1bRevokeUserPermissionRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\x12@\n\npermission\x18\x03 \x01(\x0b\x32 .doublecloud.kafka.v1.PermissionR\npermission2\xdb\x04\n\x0bUserService\x12G\n\x03Get\x12$.doublecloud.kafka.v1.GetUserRequest\x1a\x1a.doublecloud.kafka.v1.User\x12W\n\x04List\x12&.doublecloud.kafka.v1.ListUsersRequest\x1a\'.doublecloud.kafka.v1.ListUsersResponse\x12L\n\x06\x43reate\x12\'.doublecloud.kafka.v1.CreateUserRequest\x1a\x19.doublecloud.v1.Operation\x12L\n\x06Update\x12\'.doublecloud.kafka.v1.UpdateUserRequest\x1a\x19.doublecloud.v1.Operation\x12L\n\x06\x44\x65lete\x12\'.doublecloud.kafka.v1.DeleteUserRequest\x1a\x19.doublecloud.v1.Operation\x12^\n\x0fGrantPermission\x12\x30.doublecloud.kafka.v1.GrantUserPermissionRequest\x1a\x19.doublecloud.v1.Operation\x12`\n\x10RevokePermission\x12\x31.doublecloud.kafka.v1.RevokeUserPermissionRequest\x1a\x19.doublecloud.v1.OperationB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.user_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_GETUSERREQUEST']._serialized_start=191
  _globals['_GETUSERREQUEST']._serialized_end=267
  _globals['_LISTUSERSREQUEST']._serialized_start=269
  _globals['_LISTUSERSREQUEST']._serialized_end=366
  _globals['_LISTUSERSRESPONSE']._serialized_start=368
  _globals['_LISTUSERSRESPONSE']._serialized_end=492
  _globals['_CREATEUSERREQUEST']._serialized_start=494
  _globals['_CREATEUSERREQUEST']._serialized_end=605
  _globals['_UPDATEUSERREQUEST']._serialized_start=608
  _globals['_UPDATEUSERREQUEST']._serialized_end=1038
  _globals['_UPDATEUSERREQUEST_UPDATESPEC']._serialized_start=775
  _globals['_UPDATEUSERREQUEST_UPDATESPEC']._serialized_end=1038
  _globals['_UPDATEUSERREQUEST_UPDATESPEC_UPDATEPERMISSIONS']._serialized_start=951
  _globals['_UPDATEUSERREQUEST_UPDATESPEC_UPDATEPERMISSIONS']._serialized_end=1038
  _globals['_DELETEUSERREQUEST']._serialized_start=1040
  _globals['_DELETEUSERREQUEST']._serialized_end=1119
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_start=1122
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_end=1276
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_start=1279
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_end=1434
  _globals['_USERSERVICE']._serialized_start=1437
  _globals['_USERSERVICE']._serialized_end=2040
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/visualization/v1/workbook.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+doublecloud/visualization/v1/workbook.proto\x12\x1c\x64oublecloud.visualization.v1\x1a\x1cgoogle/protobuf/struct.proto\"%\n\x0bPlainSecret\x12\x16\n\x06secret\x18\x01 \x01(\tR\x06secret\"b\n\x06Secret\x12N\n\x0cplain_secret\x18\x01 \x01(\x0b\x32).doublecloud.visualization.v1.PlainSecretH\x00R\x0bplainSecretB\x08\n\x06secret\":\n\x08Workbook\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x16.google.protobuf.ValueR\x06\x63onfig\"9\n\x07\x44\x61taset\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x16.google.protobuf.ValueR\x06\x63onfig\"<\n\nConnection\x12.\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x16.google.protobuf.ValueR\x06\x63onfigBGZEgithub.com/doublecloud/api/doublecloud/visualization/v1;visualizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.visualization.v1.workbook_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZEgithub.com/doublecloud/api/doublecloud/visualization/v1;visualization'
  _globals['_PLAINSECRET']._serialized_start=107
  _globals['_PLAINSECRET']._serialized_end=144
  _globals['_SECRET']._serialized_start=146
  _globals['_SECRET']._serialized_end=244
  _globals['_WORKBOOK']._serialized_start=246
  _globals['_WORKBOOK']._serialized_end=304
  _globals['_DATASET']._serialized_start=306
  _globals['_DATASET']._serialized_end=363
  _globals['_CONNECTION']._serialized_start=365
  _globals['_CONNECTION']._serialized_end=425
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/s3_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8doublecloud/transfer/v1/endpoint/airbyte/s3_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"\xc9\r\n\x08S3Source\x12\x18\n\x07\x64\x61taset\x18\x01 \x01(\tR\x07\x64\x61taset\x12!\n\x0cpath_pattern\x18\x02 \x01(\tR\x0bpathPattern\x12\x16\n\x06schema\x18\x03 \x01(\tR\x06schema\x12Q\n\x06\x66ormat\x18\x05 \x01(\x0b\x32\x39.doublecloud.transfer.v1.endpoint.airbyte.S3Source.FormatR\x06\x66ormat\x12W\n\x08provider\x18\x06 \x01(\x0b\x32;.doublecloud.transfer.v1.endpoint.airbyte.S3Source.ProviderR\x08provider\x1a\xd7\x02\n\x06\x46ormat\x12J\n\x03\x63sv\x18\x04 \x01(\x0b\x32\x36.doublecloud.transfer.v1.endpoint.airbyte.S3Source.CsvH\x00R\x03\x63sv\x12V\n\x07parquet\x18\x05 \x01(\x0b\x32:.doublecloud.transfer.v1.endpoint.airbyte.S3Source.ParquetH\x00R\x07parquet\x12M\n\x04\x61vro\x18\x06 \x01(\x0b\x32\x37.doublecloud.transfer.v1.endpoint.airbyte.S3Source.AvroH\x00R\x04\x61vro\x12P\n\x05jsonl\x18\x07 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.airbyte.S3Source.JsonlH\x00R\x05jsonlB\x08\n\x06\x66ormat\x1a\xfe\x01\n\x08Provider\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12)\n\x11\x61ws_access_key_id\x18\x02 \x01(\tR\x0e\x61wsAccessKeyId\x12\x31\n\x15\x61ws_secret_access_key\x18\x03 \x01(\tR\x12\x61wsSecretAccessKey\x12\x1f\n\x0bpath_prefix\x18\x04 \x01(\tR\npathPrefix\x12\x1a\n\x08\x65ndpoint\x18\x05 \x01(\tR\x08\x65ndpoint\x12\x17\n\x07use_ssl\x18\x06 \x01(\x08R\x06useSsl\x12&\n\x0fverify_ssl_cert\x18\x07 \x01(\x08R\rverifySslCert\x1a\xd6\x02\n\x03\x43sv\x12\x1c\n\tdelimiter\x18\x02 \x01(\tR\tdelimiter\x12\x1d\n\nquote_char\x18\x03 \x01(\tR\tquoteChar\x12\x1f\n\x0b\x65scape_char\x18\x04 \x01(\tR\nescapeChar\x12\x1a\n\x08\x65ncoding\x18\x05 \x01(\tR\x08\x65ncoding\x12!\n\x0c\x64ouble_quote\x18\x06 \x01(\x08R\x0b\x64oubleQuote\x12,\n\x12newlines_in_values\x18\x07 \x01(\x08R\x10newlinesInValues\x12\x1d\n\nblock_size\x18\x08 \x01(\x03R\tblockSize\x12:\n\x19\x61\x64\x64itional_reader_options\x18\t \x01(\tR\x17\x61\x64\x64itionalReaderOptions\x12)\n\x10\x61\x64vanced_options\x18\n \x01(\tR\x0f\x61\x64vancedOptions\x1a\x06\n\x04\x41vro\x1a\x9a\x03\n\x05Jsonl\x12,\n\x12newlines_in_values\x18\x02 \x01(\x08R\x10newlinesInValues\x12\x8c\x01\n\x19unexpected_field_behavior\x18\x03 \x01(\x0e\x32P.doublecloud.transfer.v1.endpoint.airbyte.S3Source.Jsonl.UnexpectedFieldBehaviorR\x17unexpectedFieldBehavior\x12\x1d\n\nblock_size\x18\x04 \x01(\x03R\tblockSize\"\xb4\x01\n\x17UnexpectedFieldBehavior\x12)\n%UNEXPECTED_FIELD_BEHAVIOR_UNSPECIFIED\x10\x00\x12$\n UNEXPECTED_FIELD_BEHAVIOR_IGNORE\x10\x01\x12#\n\x1fUNEXPECTED_FIELD_BEHAVIOR_INFER\x10\x02\x12#\n\x1fUNEXPECTED_FIELD_BEHAVIOR_ERROR\x10\x03\x1a\x63\n\x07Parquet\x12\x1f\n\x0b\x62uffer_size\x18\x02 \x01(\x03R\nbufferSize\x12\x18\n\x07\x63olumns\x18\x03 \x03(\tR\x07\x63olumns\x12\x1d\n\nbatch_size\x18\x04 \x01(\x03R\tbatchSizeBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.s3_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_S3SOURCE']._serialized_start=103
  _globals['_S3SOURCE']._serialized_end=1840
  _globals['_S3SOURCE_FORMAT']._serialized_start=373
  _globals['_S3SOURCE_FORMAT']._serialized_end=716
  _globals['_S3SOURCE_PROVIDER']._serialized_start=719
  _globals['_S3SOURCE_PROVIDER']._serialized_end=973
  _globals['_S3SOURCE_CSV']._serialized_start=976
  _globals['_S3SOURCE_CSV']._serialized_end=1318
  _globals['_S3SOURCE_AVRO']._serialized_start=1320
  _globals['_S3SOURCE_AVRO']._serialized_end=1326
  _globals['_S3SOURCE_JSONL']._serialized_start=1329
  _globals['_S3SOURCE_JSONL']._serialized_end=1739
  _globals['_S3SOURCE_JSONL_UNEXPECTEDFIELDBEHAVIOR']._serialized_start=1559
  _globals['_S3SOURCE_JSONL_UNEXPECTEDFIELDBEHAVIOR']._serialized_end=1739
  _globals['_S3SOURCE_PARQUET']._serialized_start=1741
  _globals['_S3SOURCE_PARQUET']._serialized_end=1840
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1 import endpoint_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&doublecloud/transfer/v1/transfer.proto\x12\x17\x64oublecloud.transfer.v1\x1a&doublecloud/transfer/v1/endpoint.proto\"\xfd\x03\n\x08Transfer\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32-.doublecloud.transfer.v1.Transfer.LabelsEntryR\x06labels\x12\x39\n\x06source\x18\x07 \x01(\x0b\x32!.doublecloud.transfer.v1.EndpointR\x06source\x12\x39\n\x06target\x18\x08 \x01(\x0b\x32!.doublecloud.transfer.v1.EndpointR\x06target\x12?\n\x06status\x18\n \x01(\x0e\x32\'.doublecloud.transfer.v1.TransferStatusR\x06status\x12\x39\n\x04type\x18\x0c \x01(\x0e\x32%.doublecloud.transfer.v1.TransferTypeR\x04type\x12\x18\n\x07warning\x18\x0f \x01(\tR\x07warning\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*p\n\x0cTransferType\x12\x1d\n\x19TRANSFER_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16SNAPSHOT_AND_INCREMENT\x10\x01\x12\x11\n\rSNAPSHOT_ONLY\x10\x02\x12\x12\n\x0eINCREMENT_ONLY\x10\x03*\x9b\x01\n\x0eTransferStatus\x12\x1f\n\x1bTRANSFER_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07\x43REATED\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\t\n\x05\x45RROR\x10\x06\x12\x10\n\x0cSNAPSHOTTING\x10\x07\x12\x08\n\x04\x44ONE\x10\x08\x42=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.transfer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _TRANSFER_LABELSENTRY._options = None
  _TRANSFER_LABELSENTRY._serialized_options = b'8\001'
  _globals['_TRANSFERTYPE']._serialized_start=619
  _globals['_TRANSFERTYPE']._serialized_end=731
  _globals['_TRANSFERSTATUS']._serialized_start=734
  _globals['_TRANSFERSTATUS']._serialized_end=889
  _globals['_TRANSFER']._serialized_start=108
  _globals['_TRANSFER']._serialized_end=617
  _globals['_TRANSFER_LABELSENTRY']._serialized_start=560
  _globals['_TRANSFER_LABELSENTRY']._serialized_end=617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/operation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1doublecloud/clickhouse/v1/operation_service.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"8\n\x13GetOperationRequest\x12!\n\x0coperation_id\x18\x01 \x01(\tR\x0boperationId\"f\n\x15ListOperationsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x8a\x01\n\x16ListOperationsResponse\x12\x39\n\noperations\x18\x01 \x03(\x0b\x32\x19.doublecloud.v1.OperationR\noperations\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage2\xd1\x01\n\x10OperationService\x12P\n\x03Get\x12..doublecloud.clickhouse.v1.GetOperationRequest\x1a\x19.doublecloud.v1.Operation\x12k\n\x04List\x12\x30.doublecloud.clickhouse.v1.ListOperationsRequest\x1a\x31.doublecloud.clickhouse.v1.ListOperationsResponseBAZ?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.operation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_GETOPERATIONREQUEST']._serialized_start=141
  _globals['_GETOPERATIONREQUEST']._serialized_end=197
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=199
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=301
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=304
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=442
  _globals['_OPERATIONSERVICE']._serialized_start=445
  _globals['_OPERATIONSERVICE']._serialized_end=654
# @@protoc_insertion_point(module_scope)



from setuptools import find_packages, setup

packages = find_packages(".", include=["doublecloud*"])

__version__ = "0.2.0"

setup(
    name="doublecloud",
    version=__version__,
    description="The Double.Cloud official SDK",
    url="https://github.com/doublecloud/python-sdk",
    author="DoubleCloud GmbH",
    author_email="support@double.cloud",
    license="Apache License 2.0",
    install_requires=[
        "cryptography>=39.0.2",
        "grpcio>=1.51.3",
        "protobuf>=4.22.1",
        "grpcio-tools>=1.51.3",
        "googleapis-common-protos>=1.58.0",
        "pyjwt>=2.6.0",
        "requests>=2.28.2",
        "six>=1.16.0",
    ],
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
    tests_require=["pytest"],
    setup_requires=["wheel"],
    packages=packages,
    zip_safe=False,
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from doublecloud.network.v1 import network_connection_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__pb2
from doublecloud.network.v1 import network_connection_service_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2


class NetworkConnectionServiceStub(object):
    """A set of methods for managing Networks Connection.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Get',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.FromString,
                )
        self.List = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/List',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.SerializeToString,
                response_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Create',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Delete',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class NetworkConnectionServiceServicer(object):
    """A set of methods for managing Networks Connection.
    """

    def Get(self, request, context):
        """Returns the specified Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves a list of Network Connections of the specified Project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetworkConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.FromString,
                    response_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'doublecloud.network.v1.NetworkConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NetworkConnectionService(object):
    """A set of methods for managing Networks Connection.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Get',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/List',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.SerializeToString,
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Create',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Delete',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/network/v1/network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$doublecloud/network/v1/network.proto\x12\x16\x64oublecloud.network.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xb9\x05\n\x07Network\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x03 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x04 \x01(\tR\x08regionId\x12;\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12&\n\x0fipv4_cidr_block\x18\x08 \x01(\tR\ripv4CidrBlock\x12&\n\x0fipv6_cidr_block\x18\t \x01(\tR\ripv6CidrBlock\x12\x45\n\x06status\x18\n \x01(\x0e\x32-.doublecloud.network.v1.Network.NetworkStatusR\x06status\x12#\n\rstatus_reason\x18\x0b \x01(\tR\x0cstatusReason\x12@\n\x03\x61ws\x18\x0c \x01(\x0b\x32,.doublecloud.network.v1.AwsExternalResourcesH\x00R\x03\x61ws\x12\x1f\n\x0bis_external\x18\r \x01(\x08R\nisExternal\"\x9a\x01\n\rNetworkStatus\x12\x1a\n\x16NETWORK_STATUS_INVALID\x10\x00\x12\x1b\n\x17NETWORK_STATUS_CREATING\x10\x01\x12\x19\n\x15NETWORK_STATUS_ACTIVE\x10\x02\x12\x1b\n\x17NETWORK_STATUS_DELETING\x10\x03\x12\x18\n\x14NETWORK_STATUS_ERROR\x10\x04\x42\x14\n\x12\x65xternal_resources\"\xdf\x03\n\x14\x41wsExternalResources\x12\x15\n\x06vpc_id\x18\x01 \x01(\tR\x05vpcId\x12M\n\x07subnets\x18\x02 \x03(\x0b\x32\x33.doublecloud.network.v1.AwsExternalResources.SubnetR\x07subnets\x12*\n\x11security_group_id\x18\x03 \x01(\tR\x0fsecurityGroupId\x12;\n\naccount_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\taccountId\x12>\n\x0ciam_role_arn\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\niamRoleArn\x12\x37\n\x08stack_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07stackId\x12L\n\x13\x63\x66_template_version\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x11\x63\x66TemplateVersion\x1a\x31\n\x06Subnet\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07zone_id\x18\x02 \x01(\tR\x06zoneIdB;Z9github.com/doublecloud/api/doublecloud/network/v1;networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.network.v1.network_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/doublecloud/api/doublecloud/network/v1;network'
  _globals['_NETWORK']._serialized_start=130
  _globals['_NETWORK']._serialized_end=827
  _globals['_NETWORK_NETWORKSTATUS']._serialized_start=651
  _globals['_NETWORK_NETWORKSTATUS']._serialized_end=805
  _globals['_AWSEXTERNALRESOURCES']._serialized_start=830
  _globals['_AWSEXTERNALRESOURCES']._serialized_end=1309
  _globals['_AWSEXTERNALRESOURCES_SUBNET']._serialized_start=1260
  _globals['_AWSEXTERNALRESOURCES_SUBNET']._serialized_end=1309
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import clickhouse_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_clickhouse__pb2
from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2
from doublecloud.transfer.v1.endpoint import kafka_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_kafka__pb2
from doublecloud.transfer.v1.endpoint import mongo_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_mongo__pb2
from doublecloud.transfer.v1.endpoint import mysql_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_mysql__pb2
from doublecloud.transfer.v1.endpoint import postgres_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_postgres__pb2
from doublecloud.transfer.v1.endpoint.airbyte import s3_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_s3__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import redshift_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_redshift__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import aws_cloud_trail_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_aws__cloud__trail__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import bigquery_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_bigquery__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import mssql_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_mssql__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import amazon_ads_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_amazon__ads__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import facebook_marketing_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_facebook__marketing__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import linkedin_ads_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_linkedin__ads__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import instagram_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_instagram__source__pb2
from doublecloud.transfer.v1.endpoint.airbyte import google_ads_source_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_airbyte_dot_google__ads__source__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&doublecloud/transfer/v1/endpoint.proto\x12\x17\x64oublecloud.transfer.v1\x1a\x31\x64oublecloud/transfer/v1/endpoint/clickhouse.proto\x1a-doublecloud/transfer/v1/endpoint/common.proto\x1a,doublecloud/transfer/v1/endpoint/kafka.proto\x1a,doublecloud/transfer/v1/endpoint/mongo.proto\x1a,doublecloud/transfer/v1/endpoint/mysql.proto\x1a/doublecloud/transfer/v1/endpoint/postgres.proto\x1a\x38\x64oublecloud/transfer/v1/endpoint/airbyte/s3_source.proto\x1a>doublecloud/transfer/v1/endpoint/airbyte/redshift_source.proto\x1a\x45\x64oublecloud/transfer/v1/endpoint/airbyte/aws_cloud_trail_source.proto\x1a>doublecloud/transfer/v1/endpoint/airbyte/bigquery_source.proto\x1a;doublecloud/transfer/v1/endpoint/airbyte/mssql_source.proto\x1a@doublecloud/transfer/v1/endpoint/airbyte/amazon_ads_source.proto\x1aHdoublecloud/transfer/v1/endpoint/airbyte/facebook_marketing_source.proto\x1a\x42\x64oublecloud/transfer/v1/endpoint/airbyte/linkedin_ads_source.proto\x1a?doublecloud/transfer/v1/endpoint/airbyte/instagram_source.proto\x1a@doublecloud/transfer/v1/endpoint/airbyte/google_ads_source.proto\"\xb8\x02\n\x08\x45ndpoint\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x45\n\x06labels\x18\x06 \x03(\x0b\x32-.doublecloud.transfer.v1.Endpoint.LabelsEntryR\x06labels\x12\x45\n\x08settings\x18\x34 \x01(\x0b\x32).doublecloud.transfer.v1.EndpointSettingsR\x08settings\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb8\x0f\n\x10\x45ndpointSettings\x12R\n\x0cmysql_source\x18\x01 \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.MysqlSourceH\x00R\x0bmysqlSource\x12[\n\x0fpostgres_source\x18\x02 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.PostgresSourceH\x00R\x0epostgresSource\x12R\n\x0ckafka_source\x18\x08 \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.KafkaSourceH\x00R\x0bkafkaSource\x12R\n\x0cmongo_source\x18\t \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.MongoSourceH\x00R\x0bmongoSource\x12\x61\n\x11\x63lickhouse_source\x18\x10 \x01(\x0b\x32\x32.doublecloud.transfer.v1.endpoint.ClickhouseSourceH\x00R\x10\x63lickhouseSource\x12Q\n\ts3_source\x18| \x01(\x0b\x32\x32.doublecloud.transfer.v1.endpoint.airbyte.S3SourceH\x00R\x08s3Source\x12s\n\x15\x61ws_cloudtrail_source\x18\x7f \x01(\x0b\x32=.doublecloud.transfer.v1.endpoint.airbyte.AWSCloudTrailSourceH\x00R\x13\x61wsCloudtrailSource\x12\x65\n\x10\x62ig_query_source\x18\x80\x01 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.airbyte.BigQuerySourceH\x00R\x0e\x62igQuerySource\x12\x80\x01\n\x19\x66\x61\x63\x65\x62ook_marketing_source\x18\x82\x01 \x01(\x0b\x32\x41.doublecloud.transfer.v1.endpoint.airbyte.FacebookMarketingSourceH\x00R\x17\x66\x61\x63\x65\x62ookMarketingSource\x12h\n\x11google_ads_source\x18\x84\x01 \x01(\x0b\x32\x39.doublecloud.transfer.v1.endpoint.airbyte.GoogleAdsSourceH\x00R\x0fgoogleAdsSource\x12h\n\x11\x61mazon_ads_source\x18\x86\x01 \x01(\x0b\x32\x39.doublecloud.transfer.v1.endpoint.airbyte.AmazonAdsSourceH\x00R\x0f\x61mazonAdsSource\x12g\n\x10instagram_source\x18\x88\x01 \x01(\x0b\x32\x39.doublecloud.transfer.v1.endpoint.airbyte.InstagramSourceH\x00R\x0finstagramSource\x12n\n\x13linkedin_ads_source\x18\x89\x01 \x01(\x0b\x32;.doublecloud.transfer.v1.endpoint.airbyte.LinkedinAdsSourceH\x00R\x11linkedinAdsSource\x12[\n\x0cmssql_source\x18\x8a\x01 \x01(\x0b\x32\x35.doublecloud.transfer.v1.endpoint.airbyte.MSSQLSourceH\x00R\x0bmssqlSource\x12\x64\n\x0fredshift_source\x18\x8b\x01 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.airbyte.RedshiftSourceH\x00R\x0eredshiftSource\x12R\n\x0cmysql_target\x18\x65 \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.MysqlTargetH\x00R\x0bmysqlTarget\x12[\n\x0fpostgres_target\x18\x66 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.PostgresTargetH\x00R\x0epostgresTarget\x12\x61\n\x11\x63lickhouse_target\x18h \x01(\x0b\x32\x32.doublecloud.transfer.v1.endpoint.ClickhouseTargetH\x00R\x10\x63lickhouseTarget\x12R\n\x0ckafka_target\x18n \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.KafkaTargetH\x00R\x0bkafkaTarget\x12R\n\x0cmongo_target\x18o \x01(\x0b\x32-.doublecloud.transfer.v1.endpoint.MongoTargetH\x00R\x0bmongoTargetB\n\n\x08settingsB=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _ENDPOINT_LABELSENTRY._options = None
  _ENDPOINT_LABELSENTRY._serialized_options = b'8\001'
  _globals['_ENDPOINT']._serialized_start=1010
  _globals['_ENDPOINT']._serialized_end=1322
  _globals['_ENDPOINT_LABELSENTRY']._serialized_start=1265
  _globals['_ENDPOINT_LABELSENTRY']._serialized_end=1322
  _globals['_ENDPOINTSETTINGS']._serialized_start=1325
  _globals['_ENDPOINTSETTINGS']._serialized_end=3301
# @@protoc_insertion_point(module_scope)
